@@ -1,6 +1,8 @@
 import os
 import hashlib
 import json
+import pathlib
+from datetime import datetime, timedelta
 
 cache_path = '../.cache'
 
@@ -13,40 +15,46 @@ def get_hash(query):
         -------
 
         hash : str
-            Md5 хзш
+            Md5 хэш
     """
     return hashlib.md5(query.encode('utf-8')).hexdigest()
 
 
-def get_cache(query):
+def get_cache(query, login='default'):
     """
         Получить объект из кэша по его хэшу
 
-         Parameters
+        Parameters
         ----------
 
         query : str
-            md5 хзш объекта
+            md5 хэш объекта
+
+        login : str
+            Логин пользователя, добавляется в имя файла для обеспечения уникальности кэша
 
         Returns
         -------
 
         obj : json
-            Хзшрованный объект
+            Хэшрованный объект
     """
     h = get_hash(query)
+    h = login + '-' + get_hash(query)
     cache_fname = _get_cache_fname(h)
     if not os.path.exists(cache_fname):
         return None
+    if not _check_cache_is_valid(cache_fname):
+        return None
     with open(cache_fname, 'r') as f:
         return json.load(f)
 
 
-def save_cache(query, jdata):
+def save_cache(query, jdata, login='default'):
     """
         Сохранить объект в кэш-файл
 
-         Parameters
+        Parameters
         ----------
 
         query : str
@@ -54,9 +62,10 @@ def save_cache(query, jdata):
 
         jdata : json
             данные для кэширования
-         объект
+        login : str
+            Логин пользователя, добавляется в имя файла для обеспечения уникальности кэша
     """
-    h = get_hash(query)
+    h = login + '-' + get_hash(query)
     cache_file = _get_cache_fname(h)
     with open(cache_file, 'w') as f:
         json.dump(jdata, f)
@@ -67,3 +76,14 @@ def _get_cache_fname(h):
     if not os.path.exists(cache_path):
         os.makedirs(cache_path, exist_ok=True)
     return file_path
+
+
+def _check_cache_is_valid(filename):
+    fname = pathlib.Path(filename)
+    if fname.exists():
+        ctime = datetime.fromtimestamp(fname.stat().st_ctime)
+        td = datetime.now() - ctime
+        if td.total_seconds() < 86400:
+            return True
+    return False
+
